utilspie: Utilities for Python Developers
=========================

`utilspie` provides utility functions for Python Developer. Currently it has utilities for:

 - Library import: Lazy load module, delete module, reload module
 - Asynchronous call: Run multiple asynchronous process maintaining the order of response value
 - File operations: Efficient file related operations using Unix Tools


How to Contribute
-----------------

#. Check for open issues or open a fresh issue to start a discussion around a feature idea or a bug.
#. Fork `the repository`_ on GitHub to start making your changes to the **master** branch (or branch off of it).
#. Write a test which shows that the bug was fixed or that the feature works as expected.
#. Send a pull request and bug the maintainer until it gets merged and published. :) Make sure to add yourself to AUTHORS_.

.. _`the repository`: http://github.com/moin18/utilspie
.. _AUTHORS: https://github.com/moin18/utilspie/blob/master/AUTHORS.rst
